pub struct AsciiTable<'a> {
data: Vec<Vec<Cow<'a, str>>>,
max_cell_widths: Vec<usize>,
padding: usize,
}Expand description
An ascii table
Fields
data: Vec<Vec<Cow<'a, str>>>max_cell_widths: Vec<usize>padding: usizeImplementations
Sourceimpl<'a> AsciiTable<'a>
impl<'a> AsciiTable<'a>
Sourcepub fn set_padding(&mut self, padding: usize)
pub fn set_padding(&mut self, padding: usize)
Set the amount of spaces applied to each element
Sourcepub fn set_cell(&mut self, x: usize, y: usize, data: impl Into<Cow<'a, str>>)
pub fn set_cell(&mut self, x: usize, y: usize, data: impl Into<Cow<'a, str>>)
Set the value of the given cell.
Indexing starts at 0. It starts at the top left corner and ends at the bottom right.
fn fmt_row_border(&self, f: &mut Formatter<'_>) -> Result